@@ -47,7 +47,7 @@ def module_key(
         or (config.length_sort_straight and straight_import)
         or str(section_name).lower() in config.length_sort_sections
     )
-    _length_sort_maybe = length_sort and (str(len(module_name)) + ":" + module_name) or module_name
+    _length_sort_maybe = (str(len(module_name)) + ":" + module_name) if length_sort else module_name
     return f"{module_name in config.force_to_top and 'A' or 'B'}{prefix}{_length_sort_maybe}"
 
 
@@ -58,13 +58,16 @@ def section_key(
     lexicographical: bool = False,
     length_sort: bool = False,
     reverse_relative: bool = False,
+    group_by_package: bool = False,
 ) -> str:
     section = "B"
 
     if reverse_relative and line.startswith("from ."):
         match = re.match(r"^from (\.+)\s*(.*)", line)
-        if match:
+        if match:  # pragma: no cover - regex always matches if line starts with "from ."
             line = f"from {' '.join(match.groups())}"
+    if group_by_package and line.strip().startswith("from"):
+        line = line.split(" import", 1)[0]
 
     if lexicographical:
         line = _import_line_intro_re.sub("", _import_line_midline_import_re.sub(".", line))
